SegmentCell๏ƒ

Stability: Stable

What it is๏ƒ

Use SegmentCell for a single metadata-aware time interval, especially when it will live inside a SegmentTable.

Representative Signatures๏ƒ

SegmentCell(start, end)
SegmentCell.duration

Minimal Example๏ƒ

from gwexpy.table import SegmentCell

segment = SegmentCell(0, 10)

API Reference๏ƒ

The detailed generated API continues below on this page.

Inherits from: gwpy.segments.Segment

Represents a single time segment (start, end) with optional metadata.

Overview๏ƒ

SegmentCell extends the basic interval functionalities and can be stored within a SegmentTable or as individual metadata-aware intervals.

API Reference๏ƒ

.. currentmodule:: gwexpy.table

.. autoclass:: SegmentCell :members: :show-inheritance: