To release Tera Term installation package is shown in the following step:
We use CI tool for release build. For this reason, the detailed version of Visual Studio is uncontrollable. The detailed version will depend on what version is currently adopted by the CI tool at build time.
Library versions are mostly determined at this timing.
In a stable release, library versions are not updated from periodic release. (However, if a library has a security fix, we will handle it on a case-by-case basis.)
git switch main git pull --rebase git checkout -b release/5_6_0-RC
#define TT_VERSION_MAJOR 5 #define TT_VERSION_MINOR 6 #define TT_VERSION_PATCH 0 - #define TT_VERSION_SUBSTR "dev" + #define TT_VERSION_SUBSTR "RC" //#undef TT_VERSION_SUBSTRTT_VERSION_MINOR or TT_VERSION_PATCH is already incremented yet. It is incremented immediately after previous release.
git switch main git pull --rebase git checkout -b release/5_6_0
#define TT_VERSION_MAJOR 5 #define TT_VERSION_MINOR 6 #define TT_VERSION_PATCH 0 - #define TT_VERSION_SUBSTR "RC" - //#undef TT_VERSION_SUBSTR + //#define TT_VERSION_SUBSTR "dev" + #undef TT_VERSION_SUBSTR
git switch main git pull --rebase git tag -a v5.4.0 -m "Release 5.4.0" git push origin v5.4.0
git switch main git pull --rebase git checkout -b stable_5_6 git push -u origin stable_5_6
When periodic release,
git switch main git pull --rebase git checkout -b release/unfroze
#define TT_VERSION_MAJOR 5 - #define TT_VERSION_MINOR 6 + #define TT_VERSION_MINOR 7 #define TT_VERSION_PATCH 0 - //#define TT_VERSION_SUBSTR "dev" - #undef TT_VERSION_SUBSTR + #define TT_VERSION_SUBSTR "dev" + //#undef TT_VERSION_SUBSTR
#define TTSSH_VERSION_MAJOR 3 - #define TTSSH_VERSION_MINOR 6 + #define TTSSH_VERSION_MINOR 7 #define TTSSH_VERSION_PATCH 0
git switch stable_5_6 git pull --rebase git checkout -b release/unfroze
#define TT_VERSION_MAJOR 5 #define TT_VERSION_MINOR 6 - #define TT_VERSION_PATCH 0 - //#define TT_VERSION_SUBSTR "dev" - #undef TT_VERSION_SUBSTR + #define TT_VERSION_PATCH 1 + #define TT_VERSION_SUBSTR "dev" + //#undef TT_VERSION_SUBSTR
#define TTSSH_VERSION_MAJOR 3 #define TTSSH_VERSION_MINOR 6 - #define TTSSH_VERSION_PATCH 0 + #define TTSSH_VERSION_PATCH 1
When stable release,
git switch stable_5_4 git pull --rebase git checkout -b release/unfroze
#define TT_VERSION_MAJOR 5 #define TT_VERSION_MINOR 5 - #define TT_VERSION_PATCH 2 - #undef TT_VERSION_SUBSTR + #define TT_VERSION_PATCH 3 - //#define TT_VERSION_SUBSTR "dev" - #undef TT_VERSION_SUBSTR + #define TT_VERSION_SUBSTR "dev" + //#undef TT_VERSION_SUBSTR
#define TTSSH_VERSION_MAJOR 3 #define TTSSH_VERSION_MINOR 5 - #define TTSSH_VERSION_PATCH 2 + #define TTSSH_VERSION_PATCH 3
git switch main git pull --rebase git checkout -b port/changelog
After code freeze, only critical bug fix is able to committed.
Code freeze start with RC commit, and end with version increment commit..