Enumeration

NumCosmoMultiplicityFuncCastroModel

Declaration

enum NumCosmo.MultiplicityFuncCastroModel

Description [src]

Selects which of the two calibrations to evaluate. They share the whole coefficient structure but are distinct fits: NC_MULTIPLICITY_FUNC_CASTRO_MODEL_C25 does not reduce to NC_MULTIPLICITY_FUNC_CASTRO_MODEL_C23 when the dark energy term vanishes, since it carries an extra shape parameter.

See Castro et al. (2023) and Castro et al. (2025).

Members

NC_MULTIPLICITY_FUNC_CASTRO_MODEL_C23

$\Lambda(\nu)$CDM calibration, Castro et al. (2023).

  • Value: 0
  • Available since: 1.0
NC_MULTIPLICITY_FUNC_CASTRO_MODEL_C25

Dynamical dark energy calibration, Castro et al. (2025).

  • Value: 1
  • Available since: 1.0