Struct

NumCosmoMathObjArray

Description [src]

struct NcmObjArray {
  /* No available fields */
}

Reference-counted array of GObject, serializable by NcmSerialize.

A GPtrArray that holds a reference to each element.

Constructors

ncm_obj_array_new

Creates a new empty NcmObjArray.

ncm_obj_array_sized_new

Creates a new empty NcmObjArray with room for n elements.

Functions

ncm_obj_array_clear

If oa is not NULL, decreases its reference count by one and sets oa to NULL.

Instance methods

ncm_obj_array_add

Appends obj to oa, holding a reference to it.

ncm_obj_array_get
No description available.

ncm_obj_array_len
No description available.

ncm_obj_array_peek
No description available.

ncm_obj_array_ref

Increases the reference count of oa by one.

ncm_obj_array_set

Replaces the element at i, which must exist, by obj, holding a reference to it.

ncm_obj_array_unref

Decreases the reference count of oa by one. At zero, releases the references to the elements.