Array4D
Inherits from: Array, AxisApiMixin, StatisticalMethodsMixin, GwpyArray
4D Array with explicit axis management.
Array4D extends the base Array class to provide explicit management of 4 axes, each with a name and a coordinate index (1D Quantity).
Methods
isel
isel(self, indexers=None, **kwargs)
Select by integer indices along specified axes.
Inherited from AxisApiMixin. For Array4D, specifying an integer index for a dimension will reduce the dimensionality (returning a lower-dimensional array or Quantity), unlike ScalarField which always maintains 4 dimensions.
sel
sel(self, indexers=None, method='nearest', **kwargs)
Select by coordinate values along specified axes.
transpose
transpose(self, *axes)
Permute the dimensions of the array and update axis metadata.
Properties
Property |
Description |
|---|---|
|
Tuple of AxisDescriptor objects for each dimension |
|
Names of all axes |
|
Physical unit of these data |