Skip to content

Configuration

Config is loaded from the file specified by the --config parameter.

bash
uv run src/demo.py --config <path-to-config>.yaml

Global Parameters

ParameterDefaultDescription
log.log_levelINFOLog level
service.host0.0.0.0Service listen address
service.port8282Service listen port
service.cert_filessl_certs/localhost.crtSSL certificate file path
service.cert_keyssl_certs/localhost.keySSL key file path
chat_engine.model_rootmodelsModel root directory
chat_engine.handler_configsN/AHandler-specific configs

IMPORTANT

All path parameters can use absolute paths or paths relative to the project root.

Handler Configuration

See Handler Reference for per-handler configuration details.