Struct

NumCosmoWLEllipticityTraceKernelPrep

Description

struct NcWLEllipticityTraceKernelPrep {
  /* No available fields */
}

No description available.

Constructors

nc_wl_ellipticity_trace_kernel_prep_new

Allocates a new, zeroed NcWLEllipticityTraceKernelPrep. Performance-critical C code should prefer stack allocation and nc_wl_ellipticity_trace_kernel_prepare() directly; this heap-allocating constructor exists for GValue/introspection use.

Functions

nc_wl_ellipticity_trace_kernel_prep_clear

Frees prep and sets prep to NULL, it should not be used on a stack-allocated NcWLEllipticityTraceKernelPrep.

Instance methods

nc_wl_ellipticity_trace_kernel_prep_dup

Allocates a new NcWLEllipticityTraceKernelPrep and copies prep‘s contents into it.

nc_wl_ellipticity_trace_kernel_prep_free

Frees prep, it should not be used on a stack-allocated NcWLEllipticityTraceKernelPrep.