Struct

NumCosmoGalaxyShapeFactorData

Description

struct NcGalaxyShapeFactorData {
  NcGalaxyPositionFactorData* pos_data;
  NcGalaxyRedshiftFactorData* z_data;
  NcGalaxyShapePopData* pop_data;
  NcWLEllipticityFrame coord;
  gdouble epsilon_int_1;
  gdouble epsilon_int_2;
  gdouble epsilon_obs_1;
  gdouble epsilon_obs_2;
  gdouble std_noise;
  gdouble c1;
  gdouble c2;
  gdouble m;
  gpointer cdata;
  gpointer ldata;
  GDestroyNotify ldata_destroy;
  void (* ldata_read_row) (
    NcGalaxyShapeFactorData* data,
    NcGalaxyWLObs* obs,
    const guint i
  );;
  void (* ldata_write_row) (
    NcGalaxyShapeFactorData* data,
    NcGalaxyWLObs* obs,
    const guint i
  );;
  void (* ldata_required_columns) (
    NcGalaxyShapeFactorData* data,
    GList** columns
  );;
  gatomicrefcount ref_count;
}

No description available.

Structure members
pos_data: NcGalaxyPositionFactorData

No description available.

z_data: NcGalaxyRedshiftFactorData

No description available.

pop_data: NcGalaxyShapePopData

No description available.

coord: NcWLEllipticityFrame

No description available.

epsilon_int_1: gdouble

No description available.

epsilon_int_2: gdouble

No description available.

epsilon_obs_1: gdouble

No description available.

epsilon_obs_2: gdouble

No description available.

std_noise: gdouble

No description available.

c1: gdouble

No description available.

c2: gdouble

No description available.

m: gdouble

No description available.

cdata: gpointer

No description available.

ldata: gpointer

No description available.

ldata_destroy: GDestroyNotify

No description available.

ldata_read_row: void (* ldata_read_row) ( NcGalaxyShapeFactorData* data, NcGalaxyWLObs* obs, const guint i )

No description available.

ldata_write_row: void (* ldata_write_row) ( NcGalaxyShapeFactorData* data, NcGalaxyWLObs* obs, const guint i )

No description available.

ldata_required_columns: void (* ldata_required_columns) ( NcGalaxyShapeFactorData* data, GList** columns )

No description available.

ref_count: gatomicrefcount

No description available.

Constructors

nc_galaxy_shape_factor_data_new

Creates a new per-galaxy shape data. The intrinsic-ellipticity fragment is allocated by the NcGalaxyShapePop resolved from mset; the upstream fragments are referenced, not copied.

Instance methods

nc_galaxy_shape_factor_data_get_radius
No description available.

nc_galaxy_shape_factor_data_read_row

Reads the row i from obs into data, cascading to the upstream position and redshift fragments, the population fragment and the subclass fragment.

nc_galaxy_shape_factor_data_ref

Increases the reference count of data by one.

nc_galaxy_shape_factor_data_unref

Decreases the reference count of data by one. If the reference count reaches 0, the data is freed.

nc_galaxy_shape_factor_data_write_row

Writes the row i of data into obs, cascading to the upstream position and redshift fragments, the population fragment and the subclass fragment.