Struct

NumCosmoGalaxyRedshiftFactorIntegrand

Description

struct NcGalaxyRedshiftFactorIntegrand {
  NcGalaxyRedshiftFactorIntegrandFunc func;
  NcGalaxyRedshiftFactorIntegrandFreeData callback_data_free;
  NcGalaxyRedshiftFactorIntegrandCopyData callback_data_copy;
  NcGalaxyRedshiftFactorIntegrandPrepareData callback_data_prepare;
  gpointer callback_data;
}

No description available.

Structure members
func: NcGalaxyRedshiftFactorIntegrandFunc

No description available.

callback_data_free: NcGalaxyRedshiftFactorIntegrandFreeData

No description available.

callback_data_copy: NcGalaxyRedshiftFactorIntegrandCopyData

No description available.

callback_data_prepare: NcGalaxyRedshiftFactorIntegrandPrepareData

No description available.

callback_data: gpointer

No description available.

Constructors

nc_galaxy_redshift_factor_integrand_new

Creates a new integrand for the galaxy redshift data. The integrand takes the true redshift z and the per-galaxy data and returns the joint density (or its natural logarithm) at z.

Instance methods

nc_galaxy_redshift_factor_integrand_copy
No description available.

nc_galaxy_redshift_factor_integrand_eval
No description available.

nc_galaxy_redshift_factor_integrand_free
No description available.