Enumeration

NumCosmoDistanceComovingMethod

Declaration

enum NumCosmo.DistanceComovingMethod

Description [src]

Enumeration to define which method to be applied in order to compute the cosmological distances.

Members

NC_DISTANCE_COMOVING_METHOD_INT_E

Performs a numerical evaluation.

  • Value: 0
  • Available since: 1.0
NC_DISTANCE_COMOVING_METHOD_FROM_MODEL

Uses the method defined by the implementation of NcHICosmo.

  • Value: 1
  • Available since: 1.0