Enumeration

NumCosmoHICosmoVexpSParams

Declaration

enum NumCosmo.HICosmoVexpSParams

Description [src]

Scalar field parameters enumerator. This enumerator is used to access the scalar field parameters in the NcHICosmoVexp object.

The parameters NC_HICOSMO_VEXP_EM_B and NC_HICOSMO_VEXP_EM_BETA are used to define the electromagnetic coupling amplitude and scale, respectively. They are only used if the electromagnetic coupling is set to NC_HICOSMO_VEXP_EM_COUPLING_GAUSS or NC_HICOSMO_VEXP_EM_COUPLING_CAUCHY.

Members

NC_HICOSMO_VEXP_H0

Hubble constant.

  • Value: 0
  • Available since: 1.0
NC_HICOSMO_VEXP_OMEGA_C

Scalar field energy density when in a dust-like phase.

  • Value: 1
  • Available since: 1.0
NC_HICOSMO_VEXP_OMEGA_L

Scalar field energy density when in a dark energy-like phase.

  • Value: 2
  • Available since: 1.0
NC_HICOSMO_VEXP_SIGMA_PHI

Standard deviation of the scalar field wave function.

  • Value: 3
  • Available since: 1.0
NC_HICOSMO_VEXP_D_PHI

Mean of the scalar field wave function distribution.

  • Value: 4
  • Available since: 1.0
NC_HICOSMO_VEXP_ALPHA_B

Logarithm base e of the scale factor at the bounce.

  • Value: 5
  • Available since: 1.0
NC_HICOSMO_VEXP_X_B

Ratio of the scale factor today and at the bounce.

  • Value: 6
  • Available since: 1.0
NC_HICOSMO_VEXP_EM_ALPHA

Electromagnetic coupling amplitude parameter.

  • Value: 7
  • Available since: 1.0
NC_HICOSMO_VEXP_EM_BETA

Electromagnetic coupling scale.

  • Value: 8
  • Available since: 1.0