Struct

NumCosmoGalaxySDObsRedshiftIntegrand

Description

struct NcGalaxySDObsRedshiftIntegrand {
  NcGalaxySDObsRedshiftIntegrandFunc func;
  NcGalaxySDObsRedshiftIntegrandFreeData callback_data_free;
  NcGalaxySDObsRedshiftIntegrandCopyData callback_data_copy;
  NcGalaxySDObsRedshiftIntegrandPrepareData callback_data_prepare;
  gpointer callback_data;
}

No description available.

Structure members
func: NcGalaxySDObsRedshiftIntegrandFunc

No description available.

callback_data_free: NcGalaxySDObsRedshiftIntegrandFreeData

No description available.

callback_data_copy: NcGalaxySDObsRedshiftIntegrandCopyData

No description available.

callback_data_prepare: NcGalaxySDObsRedshiftIntegrandPrepareData

No description available.

callback_data: gpointer

No description available.

Constructors

nc_galaxy_sd_obs_redshift_integrand_new

Creates a new integrand for the galaxy redshift data. The integrand is a function that takes the redshift z and the galaxy redshift data data as arguments. The function should return the integrand value at z.

Instance methods

nc_galaxy_sd_obs_redshift_integrand_copy

Copies the integrand for the galaxy redshift data.

nc_galaxy_sd_obs_redshift_integrand_eval
No description available.

nc_galaxy_sd_obs_redshift_integrand_free

Frees the integrand for the galaxy redshift data.

nc_galaxy_sd_obs_redshift_integrand_prepare

Prepares the integrand for the galaxy redshift data.