Enumeration

NumCosmoClusterRedshiftImpl

Declaration

enum NumCosmo.ClusterRedshiftImpl

Description

No description available.

Members

NC_CLUSTER_REDSHIFT_P

Probability density function of the true-measured cluster redshifts.

  • Value: 0
  • Available since: 1.0
NC_CLUSTER_REDSHIFT_INTP

Probability distribution (integration over the measured redshift).

  • Value: 1
  • Available since: 1.0
NC_CLUSTER_REDSHIFT_RESAMPLE

Resample function to generate the cluster redshifts following the underlying cluster redshift distribution.

  • Value: 2
  • Available since: 1.0
NC_CLUSTER_REDSHIFT_P_LIMITS

Function to set the lower and upper limits of the to compute the integral of the cluster redshift distribution.

  • Value: 3
  • Available since: 1.0
NC_CLUSTER_REDSHIFT_N_LIMTS

Function to set the lower and upper thresholds of the observable cluster redshift to compute the normalization of the cluster redshift distribution.

  • Value: 4
  • Available since: 1.0