Enumeration

NumCosmoMultiplicityFuncMassDef

Declaration

enum NumCosmo.MultiplicityFuncMassDef

Description [src]

Spherical overdensity halo mass: $$M_\Delta = \frac{4\pi}{3} \Delta \rho_\mathrm{bg} r_\Delta^3,$$ where $\rho_\mathrm{bg}$ is the background density of the universe at redshift z, $\rho_\mathrm{bg} (z)$. For NC_HALO_DENSITY_PROFILE_MASS_DEF_VIRIAL the virial overdensity is defined as: \begin{equation}\label{def:DVir} \Delta_\mathrm{Vir} = 18 \pi^2 + 82 x - 39 x^2, \quad x \equiv \Omega_m(z) - 1. \end{equation}.

Members

NC_MULTIPLICITY_FUNC_MASS_DEF_MEAN

Halo mass defined in terms of the mean density $\rho_\mathrm{bg} = \rho_m(z)$.

  • Value: 0
  • Available since: 1.0
NC_MULTIPLICITY_FUNC_MASS_DEF_CRITICAL

Halo mass defined in terms of the critical density $\rho_\mathrm{bg} = \rho_\mathrm{crit}(z)$.

  • Value: 1
  • Available since: 1.0
NC_MULTIPLICITY_FUNC_MASS_DEF_VIRIAL

Halo mass defined in terms of virial overdensity times the critical density $\rho_\mathrm{bg} = \rho_\mathrm{crit.

  • Value: 2
  • Available since: 1.0
NC_MULTIPLICITY_FUNC_MASS_DEF_FOF

Friends of friends.

  • Value: 3
  • Available since: 1.0