Enumeration

NumCosmoReducedShearClusterMassParams

Declaration

enum NumCosmo.ReducedShearClusterMassParams

Description [src]

These parameters refers to the shear calibration, and the Voigt profile.

In particular, we consider the shear calibration as defined for STEP and STEP2 simulations: $$\hat{g}{Teo} = (1 + m)g + c,$$ where $g$ is the reduced shear, the multiplicative bias $m$ is $$ m =\left{ \begin{array}{c l} a \frac{r{gal}}{r_{PSF}} + b & \frac{r_{gal}}{r_{PSF}} < x_p \ * b & \frac{r_{gal}}{r_{PSF}} \geq x_p p \end{array}\right. $$ and $c = constant.$ $r_{gal}$ and $r_{PSF}$ are the galaxy and PSF (point spread function) sizes, respectively. See [Applegate (2014)][XApplegate2014].

Members

NC_REDUCED_SHEAR_CLUSTER_MASS_A

Shear calibration parameter.

  • Value: 0
  • Available since: 1.0
NC_REDUCED_SHEAR_CLUSTER_MASS_B

Shear calibration parameter.

  • Value: 1
  • Available since: 1.0
NC_REDUCED_SHEAR_CLUSTER_MASS_C

Shear calibration parameter.

  • Value: 2
  • Available since: 1.0
NC_REDUCED_SHEAR_CLUSTER_MASS_XP

Pivot parameter.

  • Value: 3
  • Available since: 1.0
NC_REDUCED_SHEAR_CLUSTER_MASS_VSIGMA

Voigt profile parameter, $\sigma$ is the standard deviation of the Gaussian distribution.

  • Value: 4
  • Available since: 1.0
NC_REDUCED_SHEAR_CLUSTER_MASS_VGAMMA

Voigt profile parameter, $\Gamma$ is the width of the Lorentzian profile.

  • Value: 5
  • Available since: 1.0