Struct
NumCosmoGalaxySDObsRedshiftIntegrand
Description
struct NcGalaxySDObsRedshiftIntegrand {
NcGalaxySDObsRedshiftIntegrandFunc func;
NcGalaxySDObsRedshiftIntegrandFreeData callback_data_free;
NcGalaxySDObsRedshiftIntegrandCopyData callback_data_copy;
NcGalaxySDObsRedshiftIntegrandPrepareData callback_data_prepare;
gpointer callback_data;
}
No description available.
Structure members
func:NcGalaxySDObsRedshiftIntegrandFuncNo description available.
callback_data_free:NcGalaxySDObsRedshiftIntegrandFreeDataNo description available.
callback_data_copy:NcGalaxySDObsRedshiftIntegrandCopyDataNo description available.
callback_data_prepare:NcGalaxySDObsRedshiftIntegrandPrepareDataNo description available.
callback_data:gpointerNo description available.
Constructors
nc_galaxy_sd_obs_redshift_integrand_new
Creates a new integrand for the galaxy redshift data.
The integrand is a function that takes the redshift z and the galaxy redshift data data as arguments.
The function should return the integrand value at z.