Enumeration
NumCosmoDataSNIAId
Members
-
NC_DATA_SNIA_SIMPLE_GOLD_157 -
Gold sample with 157 supernovae.
- Value:
0 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_SIMPLE_GOLD_182 -
Gold sample with 182 supernovae.
- Value:
1 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_SIMPLE_GOLD_182_FULL -
Gold sample with 182 supernovae, full dataset.
- Value:
2 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_SIMPLE_ESSENCE -
ESSENCE survey supernova sample.
- Value:
3 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_SIMPLE_LEGACY -
Legacy supernova survey sample.
- Value:
4 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_SIMPLE_UNION -
Union supernova compilation.
- Value:
5 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_SIMPLE_CfA3 -
CfA3 supernova survey sample.
- Value:
6 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_SIMPLE_UNION2 -
Union2 supernova compilation.
- Value:
7 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_SIMPLE_UNION2_1 -
Union2.1 supernova compilation.
- Value:
8 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_SIMPLE_SDSS_EMILLE -
SDSS supernova sample (Emille).
- Value:
9 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_COV_SNLS3_SYS_STAT -
SNLS3 sample with systematic and statistical covariance.
- Value:
10 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_COV_SNLS3_STAT_ONLY -
SNLS3 sample with statistical covariance only.
- Value:
11 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_COV_JLA_SNLS3_SDSS_SYS_STAT -
JLA SNIa compilation, reduced covariance already includes intrinsic, redshift and peculiar velocity variances.
- Value:
12 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_COV_JLA_SNLS3_SDSS_SYS_STAT_CMPL -
JLA SNIa compilation, complete covariance does not include intrinsic, redshift and peculiar velocity variances.
- Value:
13 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_COV_PANTHEON -
Pantheon SNIa compilation, reduced covariance already includes intrinsic, redshift and peculiar velocity variances.
- Value:
14 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_COV_PANTHEON_PLUS_SH0ES_SYS_STAT -
Pantheon SNIa compilation 2022 plus Sh0es Cepheid distance, full covariance statistics and systematics.
- Value:
15 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_COV_PANTHEON_PLUS_SH0ES_STAT -
Pantheon SNIa compilation 2022 plus Sh0es Cepheid distance, statistics covariance only.
- Value:
16 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_COV_DES_Y5_STATONLY -
Dark Energy Survey Y5 SNIa compilation, statistics covariance only.
- Value:
17 - Available since: 1.0
- Value:
-
NC_DATA_SNIA_COV_DES_Y5_STAT_SYS -
Dark Energy Survey Y5 SNIa compilation, statistics and systematics covariance.
- Value:
18 - Available since: 1.0
- Value: