Enumeration
NumCosmoClusterMassImpl
Members
-
NC_CLUSTER_MASS_P -
Probability density function of the true-observable cluster masses.
- Value:
0 - Available since: 1.0
- Value:
-
NC_CLUSTER_MASS_INTP -
Probability distribution (integration over the observable mass(es)).
- Value:
1 - Available since: 1.0
- Value:
-
NC_CLUSTER_MASS_RESAMPLE -
Resample function to generate the cluster masses following the underlying cluster mass distribution.
- Value:
2 - Available since: 1.0
- Value:
-
NC_CLUSTER_MASS_P_LIMITS -
Function to set the lower and upper limits of the to compute the integral of the cluster mass distribution.
- Value:
3 - Available since: 1.0
- Value:
-
NC_CLUSTER_MASS_N_LIMITS -
Function to set the lower and upper thresholds of the observable cluster mass to compute the normalization of the cluster mass distribution.
- Value:
4 - Available since: 1.0
- Value: