Enumeration
NumCosmoHaloDensityProfileDK14Params
Description [src]
The first three parameters, $\rho_s$, $r_s$ and $\alpha$, are the Einasto profile’s parameters. The transition term $f_{trans}$ is a function parametrized by $r_t$, $beta$ and $\gamma$. These two functions determine the inner profile, whereas the outer profile is parametrized br $b_e$ and $s_e$.
Members
-
NC_HALO_DENSITY_PROFILE_DK14_RT -
The truncation radius, the radius where the profile steepens beyond the Einasto profile, in $kpc/h$.
- Value:
0 - Available since: 1.0
- Value:
-
NC_HALO_DENSITY_PROFILE_DK14_BETA -
Sharpness of the steepening.
- Value:
1 - Available since: 1.0
- Value:
-
NC_HALO_DENSITY_PROFILE_DK14_GAMMA -
Asymptotic negative slope of the steepening term.
- Value:
2 - Available since: 1.0
- Value:
-
NC_HALO_DENSITY_PROFILE_DK14_BE -
Amplitude of one factor of the outer profile.
- Value:
3 - Available since: 1.0
- Value:
-
NC_HALO_DENSITY_PROFILE_DK14_SE -
Slope of the outer profile.
- Value:
4 - Available since: 1.0
- Value: