API Version: 1.0
Library Version: 0.27.0
Generated by gi-docgen 2026.1
enum NumCosmo.DistanceComovingMethod
Enumeration to define which method to be applied in order to compute the cosmological distances.
NC_DISTANCE_COMOVING_METHOD_INT_E
Performs a numerical evaluation.
0
NC_DISTANCE_COMOVING_METHOD_FROM_MODEL
Uses the method defined by the implementation of NcHICosmo.
NcHICosmo
1
Content