Struct
NumCosmoHIPertTwoFluidsStateInterp
Description
struct NcHIPertTwoFluidsStateInterp {
NcmSpline* mode1_splines[];
NcmSpline* mode2_splines[];
NcHIPertITwoFluidsState state;
gint interp_mode;
}
No description available.
Structure members
mode1_splines:NcmSplineNo description available.
mode2_splines:NcmSplineNo description available.
state:NcHIPertITwoFluidsStateNo description available.
interp_mode:gintNo description available.
Instance methods
nc_hipert_two_fluids_state_interp_dup
Creates a shallow copy of sinterp. The internal splines for both modes are not
duplicated but shared via reference counting (i.e., the references are increased
using ncm_spline_ref()).
nc_hipert_two_fluids_state_interp_eval
Interpolates the perturbation state at the point x using the splines stored in
sinterp. The result contains the complex values of the variables $\zeta$, $Q$,
$P_\zeta$, and $P_Q$ for both quantized modes.
nc_hipert_two_fluids_state_interp_free
Frees the memory allocated for sinterp and releases the references to all internally
held splines for both modes.