Struct

NumCosmoMathCSQ1DState

Description [src]

struct NcmCSQ1DState {
  /* No available fields */
}

A point $(\alpha, \gamma)$ of the hyperbolic plane at a time $t$ in a given NcmCSQ1DFrame. The point is a complex structure $J_{ab}$, which fixes a mode of the oscillator up to a time-dependent phase, see ncm_csq1d_state_get_J().

Constructors

ncm_csq1d_state_new

Creates a new and uninitialized NcmCSQ1DState.

Instance methods

ncm_csq1d_state_compute_distance

The hyperbolic distance $d$ between the points of state and state1, which must have the same frame and time: $$\cosh d = \cosh\alpha\cosh\alpha_1\cosh(\gamma - \gamma_1) - \sinh\alpha\sinh\alpha_1.$$.

ncm_csq1d_state_copy

Creates a copy of state.

ncm_csq1d_state_free

Frees state.

ncm_csq1d_state_get_J

Gets the components of the complex structure $J_{ab}$ of state, the symmetric, positive definite matrix of unit determinant the point $(\alpha, \gamma)$ represents. For the mode $(\phi, P_\phi)$ of ncm_csq1d_state_get_phi_Pphi(), $J_{11} = 2\vert\phi\vert^2$, $J_{22} = 2\vert P_\phi\vert^2$ and $J_{12} = \phi P_\phi^ + \phi^ P_\phi$.

ncm_csq1d_state_get_ag

Gets the point $(\alpha, \gamma)$ of state.

ncm_csq1d_state_get_circle

Sets cstate to the point at hyperbolic distance r from state in the direction theta; $\theta = 0$ increases $\alpha$ by r at fixed $\gamma$. cstate keeps the frame and time of state.

ncm_csq1d_state_get_frame
No description available.

ncm_csq1d_state_get_minkowski

Gets the spatial coordinates of state on the hyperboloid $x_0^2 - x_1^2 - x_2^2 = 1$, with $x_0 = \cosh\alpha\cosh\gamma$.

ncm_csq1d_state_get_phi_Pphi

Gets the eigenvector $(\phi, P_\phi)$ of the complex structure of state in the phase where $\phi$ is real and positive, \begin{align} \phi &= \sqrt{\frac{e^{-\gamma}\cosh\alpha}{2}}, \ P_\phi &= -\tanh\alpha\,\sqrt{\frac{e^{\gamma}\cosh\alpha}{2}} - i\sqrt{\frac{e^{\gamma}}{2\cosh\alpha}}, \end{align} normalized by $\phi P_\phi^ - \phi^ P_\phi = i$. In this phase $e^{-i\theta(t)}(\phi, P_\phi)$ solves the equations of motion, with $\theta = \int\nu\,\mathrm{d}t + \delta\theta$ from ncm_csq1d_eval_int_nu() and ncm_csq1d_eval_delta_theta_at(). This phase differs from the published one by a factor that depends on time through $\alpha$; see the CSQ1D Formalism page.

ncm_csq1d_state_get_poincare_disc

Gets state as a point of the PoincarĂ© disc, the projection of the hyperboloid point of ncm_csq1d_state_get_minkowski() from $(-1, 0, 0)$.

ncm_csq1d_state_get_poincare_half_plane

Gets state as the point $x + iy$ of the PoincarĂ© upper half-plane, where $J_{11} = (x^2 + y^2)/y$, $J_{12} = -x/y$ and $J_{22} = 1/y$.

ncm_csq1d_state_get_time
No description available.

ncm_csq1d_state_get_um

Gets state as $(\chi, U_-)$, see ncm_csq1d_state_set_um().

ncm_csq1d_state_get_up

Gets state as $(\chi, U_+)$, see ncm_csq1d_state_set_up().

ncm_csq1d_state_set_ag

Sets state to the point $(\alpha, \gamma)$ of frame at t.

ncm_csq1d_state_set_um

Sets state from $(\chi, U_-)$; $e^{U_-}$ is the component $J_{11}$ of the complex structure, see ncm_csq1d_state_get_J().

ncm_csq1d_state_set_up

Sets state from $(\chi, U_+)$; $e^{U_+}$ is the component $J_{22}$ of the complex structure, see ncm_csq1d_state_get_J().