Struct

NumCosmoMathTriVec

Description

struct NcmTriVec {
  /* No available fields */
}

No description available.

Constructors

ncm_trivec_new

Creates a zero NcmTriVec.

ncm_trivec_new_astro_coord

Creates the vector with the given astronomical coordinates, see ncm_trivec_set_astro_coord().

ncm_trivec_new_astro_ra_dec

Creates the vector with the given astronomical coordinates, see ncm_trivec_set_astro_ra_dec().

ncm_trivec_new_full
No description available.

ncm_trivec_new_full_c
No description available.

ncm_trivec_new_sphere

Creates the vector with the given spherical coordinates, see ncm_trivec_set_spherical_coord().

Instance methods

ncm_trivec_dot
No description available.

ncm_trivec_dup
No description available.

ncm_trivec_free

Frees v.

ncm_trivec_get_astro_coord

Computes the astronomical coordinates of v, with $\delta \in [-\pi/2, \pi/2]$ and $\alpha \in (-\pi, \pi]$.

ncm_trivec_get_astro_ra_dec

Same as ncm_trivec_get_astro_coord() with the angles in degrees.

ncm_trivec_get_phi
No description available.

ncm_trivec_get_spherical_coord

Computes the spherical coordinates of v, with $\theta \in [0, \pi]$ and $\phi \in (-\pi, \pi]$.

ncm_trivec_memcpy

Copies orig into dest.

ncm_trivec_norm
No description available.

ncm_trivec_normalize

Divides v by its norm.

ncm_trivec_scale

Multiplies v by scale.

ncm_trivec_set_0

Sets v to zero.

ncm_trivec_set_astro_coord

Sets v to $(r\cos\delta\cos\alpha, r\cos\delta\sin\alpha, r\sin\delta)$.

ncm_trivec_set_astro_ra_dec

Same as ncm_trivec_set_astro_coord() with the angles in degrees.

ncm_trivec_set_spherical_coord

Sets v to $(r\sin\theta\cos\phi, r\sin\theta\sin\phi, r\cos\theta)$.