Struct

NumCosmoMathObjDictInt

Description [src]

struct NcmObjDictInt {
  /* No available fields */
}

Reference-counted dictionary from integers to GObject, serializable by NcmSerialize.

A GHashTable that holds a reference to each value.

Constructors

ncm_obj_dict_int_new

Creates a new empty NcmObjDictInt.

Functions

ncm_obj_dict_int_clear

If odi is not NULL, decreases its reference count by one and sets odi to NULL.

Instance methods

ncm_obj_dict_int_add

Stores obj under key, holding a reference to it. A value already under key is replaced.

ncm_obj_dict_int_get
No description available.

ncm_obj_dict_int_keys
No description available.

ncm_obj_dict_int_len
No description available.

ncm_obj_dict_int_peek
No description available.

ncm_obj_dict_int_ref

Increases the reference count of odi by one.

ncm_obj_dict_int_set

Same as ncm_obj_dict_int_add().

ncm_obj_dict_int_unref

Decreases the reference count of odi by one. At zero, releases the references to the values.