Struct
NumCosmoMathObjDictStr
Description [src]
struct NcmObjDictStr {
/* No available fields */
}
Reference-counted dictionary from strings to GObject, serializable by
NcmSerialize.
A GHashTable that holds a copy of each key and a reference to each value.
Functions
ncm_obj_dict_str_clear
If ods is not NULL, decreases its reference count by one and sets ods to NULL.
Instance methods
ncm_obj_dict_str_add
Stores obj under key, holding a reference to it. A value already under key is replaced.
ncm_obj_dict_str_unref
Decreases the reference count of ods by one. At zero, releases the keys and the references to the values.