Struct
NumCosmoMathTriVec
Constructors
ncm_trivec_new_astro_coord
Creates the vector with the given astronomical coordinates, see ncm_trivec_set_astro_coord().
ncm_trivec_new_astro_ra_dec
Creates the vector with the given astronomical coordinates, see ncm_trivec_set_astro_ra_dec().
ncm_trivec_new_sphere
Creates the vector with the given spherical coordinates, see ncm_trivec_set_spherical_coord().
Instance methods
ncm_trivec_get_astro_coord
Computes the astronomical coordinates of v, with $\delta \in [-\pi/2, \pi/2]$ and
$\alpha \in (-\pi, \pi]$.
ncm_trivec_get_spherical_coord
Computes the spherical coordinates of v, with $\theta \in [0, \pi]$ and $\phi \in (-\pi, \pi]$.