Enumeration
NumCosmoMathCatalogColType
Description [src]
Logical type of a catalog column. All values are physically stored in the double backing matrix; the type is schema metadata used to restore the intended dtype when converting to/from external table formats.
Members
-
NCM_CATALOG_COL_TYPE_INVALID -
Invalid column type.
- Value:
-1 - Available since: 1.0
- Value:
-
NCM_CATALOG_COL_TYPE_DOUBLE -
A real-valued column.
- Value:
0 - Available since: 1.0
- Value:
-
NCM_CATALOG_COL_TYPE_INT -
An integer-valued column (stored losslessly in the double matrix).
- Value:
1 - Available since: 1.0
- Value:
-
NCM_CATALOG_COL_TYPE_BOOL -
A boolean-valued column (stored as 0.0/1.0 in the double matrix).
- Value:
2 - Available since: 1.0
- Value: