Enumeration

NumCosmoMathMSetTransKernCatSampling

Declaration

enum NumCosmoMath.MSetTransKernCatSampling

Description [src]

Sampling methods.

Members

NCM_MSET_TRANS_KERN_CAT_SAMPLING_CHOOSE

Sampling by choosing radomly points from the catalog.

  • Value: 0
  • Available since: 1.0
NCM_MSET_TRANS_KERN_CAT_SAMPLING_RBF_INTERP

Sampling from the RBF interpolation built using the last ensemble from the catalog.

  • Value: 1
  • Available since: 1.0
NCM_MSET_TRANS_KERN_CAT_SAMPLING_KDE

Sampling from the KDE estimate built using the last ensemble from the catalog.

  • Value: 2
  • Available since: 1.0