Enumeration

NumCosmoMathMPIJobCtrlMsg

Declaration

enum NumCosmoMath.MPIJobCtrlMsg

Description [src]

Control messages from master to slave. All messages have the same size, specifying tag #NCM_MPI_CTRL_TAG_CMD.

Members

NCM_MPI_CTRL_SLAVE_INIT

Slave should receive a serialized job and initializes itself.

  • Value: 0
  • Available since: 1.0
NCM_MPI_CTRL_SLAVE_FREE

Slave should free its resources and waits for a new job.

  • Value: 1
  • Available since: 1.0
NCM_MPI_CTRL_SLAVE_KILL

Slave should free its resources and exits, the rank will not be used anymore.

  • Value: 2
  • Available since: 1.0
NCM_MPI_CTRL_SLAVE_WORK

Slave should receive a serialized input, runs the job, and returns a serialized result.

  • Value: 3
  • Available since: 1.0