Struct

NumCosmoMathIntegralFixed

Description [src]

struct NcmIntegralFixed {
  /* No available fields */
}

Fixed-point numerical integration structure. Contains integration bounds and nodes for fixed Gauss-Legendre or other quadrature schemes.

Functions

ncm_integral_fixed_new

This function prepares the NcmIntegralFixed with a grid with n_nodes - 1 intervals beteween xl and xu. In each interval it uses a fixed order (rule_n) Gauss-Legendre integration rule to determine the interval inner points. This results in a grid with (n_nodes - 1) * rule_n points.

Instance methods

ncm_integral_fixed_calc_nodes

This function calculates the nodes of the NcmIntegralFixed. It uses the Gauss-Legendre integration rule to determine the interval inner points.

ncm_integral_fixed_free

This function frees the memory associated to NcmIntegralFixed.

ncm_integral_fixed_integ_mult

This function evaluates the integral of the function integ->f over the interval [xi, xf] using the nodes calculated by #ncm_integral_fixed_calc_nodes. It uses the Gauss-Legendre integration rule to determine the interval inner points. This function multiplies the integrand by the function F.

ncm_integral_fixed_integ_posdef_mult

This function computes the integral of the function integ->f over the interval starting at max and going to the left using the nodes calculated by #ncm_integral_fixed_calc_nodes. It uses the Gauss-Legendre integration rule to determine the interval inner points. This function multiplies the integrand by the function F. It stops when the relative error is less than reltol.

ncm_integral_fixed_nodes_eval

This function evaluates the integral of the function integ->f over the interval [xi, xf] using the nodes calculated by #ncm_integral_fixed_calc_nodes.