Struct

NumCosmoMathRNGDiscrete

Description

struct NcmRNGDiscrete {
  /* No available fields */
}

No description available.

Constructors

ncm_rng_discrete_new

Creates a new NcmRNGDiscrete. This object is used to generate random numbers from a discrete distribution for the given set of weights.

Instance methods

ncm_rng_discrete_copy

Creates a copy of rng_discrete.

ncm_rng_discrete_free

Frees the memory allocated by rng.