Enumeration

NumCosmoMathVectorInternal

Declaration

enum NumCosmoMath.VectorInternal

Description [src]

This enumerator is only used internally. Only by developers.

Members

NCM_VECTOR_SLICE

Uses g_slice_* family functions from Glib to alloc and free memory segments.

  • Value: 0
  • Available since: 1.0
NCM_VECTOR_GSL_VECTOR

Uses gsl_vector from GSL as the base object.

  • Value: 1
  • Available since: 1.0
NCM_VECTOR_MALLOC

Uses malloc for memory allocation and free functions.

  • Value: 2
  • Available since: 1.0
NCM_VECTOR_ARRAY

Uses g_array from Glib as base.

  • Value: 3
  • Available since: 1.0
NCM_VECTOR_DERIVED

Uses another NcmVector (for example, if it is getting a subvector from a NcmVector).

  • Value: 4
  • Available since: 1.0