Struct

NumCosmoMathComplex

Description

struct NcmComplex {
  /* No available fields */
}

No description available.

Constructors

ncm_complex_new

Allocates a new complex number.

Functions

ncm_complex_clear

Frees c and sets c to NULL, it should not be used on a statically allocated NcmComplex.

Instance methods

ncm_complex_Abs

Returns the absolute value of c.

ncm_complex_Im

Returns the imaginary part of c.

ncm_complex_Re

Returns the real part of c.

ncm_complex_dup

Allocates a new complex number and copy the contents of c to it.

ncm_complex_free

Frees c, it should not be used on a statically allocated NcmComplex.

ncm_complex_mul_real

Computes c1 = c1 * v.

ncm_complex_res_add_mul

Computes c1 = c1 + c2 * c3, assuming that c1 and c2 are different.

ncm_complex_res_add_mul_real

Computes c1 = c1 + c2 * v, assuming that c1 and c2 are different.

ncm_complex_res_mul

Computes c1 = c1 * c2, assuming that c1 and c2 are different.

ncm_complex_set

Sets c to $a + I b$.

ncm_complex_set_zero

Sets c to $0 + I 0$.