Struct

NumCosmoMathSFSphericalHarmonicsYArray

Description [src]

struct NcmSFSphericalHarmonicsYArray {
  gint l;
  gint l0;
  gint m;
  gint len;
  gdouble x[6];
  gdouble sqrt1mx2[6];
  gdouble Yl0m[12];
  gdouble Ylm[12];
  NcmSFSphericalHarmonicsK* Klm;
  NcmSFSphericalHarmonics* spha;
  gdouble abstol;
}

Recurrence array boxed object.

Structure members
l: gint

$l$.

l0: gint

$l_0$.

m: gint

$m$.

len: gint

No description available.

x: gdouble

Array of $x$.

sqrt1mx2: gdouble

Array of $\sqrt{1-x^2}$.

Yl0m: gdouble

Array of $Y_{l_0}^m$.

Ylm: gdouble

Array of $Y_{l}^m$.

Klm: NcmSFSphericalHarmonicsK

NcmSFSphericalHarmonicsK pointer.

spha: NcmSFSphericalHarmonics

Pointer to parent NcmSFSphericalHarmonics.

abstol: gdouble

Absolute tolerance.

Constructors

ncm_sf_spherical_harmonics_Y_array_new

Creates a new NcmSFSphericalHarmonicsYArray object. This object is used to contain the results of the computation of the spherical harmonics for an array of angles $\theta_i$ with length len.

Instance methods

ncm_sf_spherical_harmonics_Y_array_dup

Duplicates a NcmSFSphericalHarmonicsYArray object.

ncm_sf_spherical_harmonics_Y_array_free

Frees a NcmSFSphericalHarmonicsYArray object.

ncm_sf_spherical_harmonics_Y_array_get_l
No description available.

ncm_sf_spherical_harmonics_Y_array_get_lm
No description available.

ncm_sf_spherical_harmonics_Y_array_get_m
No description available.

ncm_sf_spherical_harmonics_Y_array_get_x
No description available.

ncm_sf_spherical_harmonics_Y_array_next_l
No description available.

ncm_sf_spherical_harmonics_Y_array_next_l2
No description available.

ncm_sf_spherical_harmonics_Y_array_next_l4
No description available.

ncm_sf_spherical_harmonics_Y_array_next_m
No description available.

ncm_sf_spherical_harmonics_Y_array_reset
No description available.