Enumeration

NumCosmoMathIntegralNDMethod

Declaration

enum NumCosmoMath.IntegralNDMethod

Description [src]

The type of the method used to perform the integral.

Members

NCM_INTEGRAL_ND_METHOD_CUBATURE_H

Adaptive integration by partitioning the integration domain (“h-adaptive”) and using the same fixed-degree quadrature in each subdomain, recursively, until convergence is achieved.

  • Value: 0
  • Available since: 1.0
NCM_INTEGRAL_ND_METHOD_CUBATURE_P

Adaptive integration by increasing the degree of (tensor-product Clenshaw-Curtis) quadrature rules (“p-adaptive”), rather than subdividing the domain (“h-adaptive”). Possibly better for smooth integrands in low dimensions.

  • Value: 1
  • Available since: 1.0
NCM_INTEGRAL_ND_METHOD_CUBATURE_H_V

Same as NCM_INTEGRAL_ND_METHOD_CUBATURE_H with vectorized integrand.

  • Value: 2
  • Available since: 1.0
NCM_INTEGRAL_ND_METHOD_CUBATURE_P_V

Same as NCM_INTEGRAL_ND_METHOD_CUBATURE_P with vectorized integrand.

  • Value: 3
  • Available since: 1.0