Struct

NumCosmoMathTriVec

Description

struct NcmTriVec {
  /* No available fields */
}

No description available.

Constructors

ncm_trivec_new

Creates a new empty NcmTriVec.

ncm_trivec_new_astro_coord

Creates a new NcmTriVec with the given astronomical coordinates. The astronomical coordinates are the declination and the right ascension. The declination is the angle between the vector and the celestial equator, and the right ascension is the angle between the projection of the vector in the celestial equator and the vernal equinox. The angles are in radians.

ncm_trivec_new_astro_ra_dec

Creates a new NcmTriVec with the given astronomical coordinates. The astronomical coordinates are the declination and the right ascension. The declination is the angle between the vector and the celestial equator, and the right ascension is the angle between the projection of the vector in the celestial equator and the vernal equinox. The angles are in degrees.

ncm_trivec_new_full

Creates a new NcmTriVec with the given components.

ncm_trivec_new_full_c

Creates a new NcmTriVec with the given components.

ncm_trivec_new_sphere

Creates a new NcmTriVec with the given spherical coordinates. The spherical coordinates are the radius, the polar angle and the azimuthal angle. The polar angle is the angle between the vector and the z-axis, and the azimuthal angle is the angle between the projection of the vector in the xy-plane and the x-axis.

Instance methods

ncm_trivec_dot

Calculates the dot product of two NcmTriVec.

ncm_trivec_dup

Duplicates a NcmTriVec.

ncm_trivec_free

Frees a NcmTriVec.

ncm_trivec_get_astro_coord

Computes the astronomical coordinates of a NcmTriVec. See ncm_trivec_set_astro_coord() for details.

ncm_trivec_get_astro_ra_dec

Computes the astronomical coordinates of a NcmTriVec. See ncm_trivec_set_astro_ra_dec() for details.

ncm_trivec_get_phi

Gets the azimuthal angle of a NcmTriVec.

ncm_trivec_get_spherical_coord

Computes the spherical coordinates of a NcmTriVec.

ncm_trivec_memcpy

Copies a NcmTriVec.

ncm_trivec_norm

Calculates the norm of a NcmTriVec.

ncm_trivec_normalize

Normalize a NcmTriVec.

ncm_trivec_scale

Scale a NcmTriVec.

ncm_trivec_set_0

Sets a NcmTriVec to zero.

ncm_trivec_set_astro_coord

Sets the astronomical coordinates of a NcmTriVec. The astronomical coordinates are the declination and the right ascension. The vector is defined as: $$\vec{v} = (\cos(\delta) \cos(\alpha), \cos(\delta) \sin(\alpha), \sin(\delta)).$$.

ncm_trivec_set_astro_ra_dec

Sets the astronomical coordinates of a NcmTriVec. The astronomical coordinates are the declination and the right ascension. The declination is the angle between the vector and the z-axis, and the right ascension is the angle between the projection of the vector in the xy-plane and the x-axis. The declination and the right ascension are given in degrees.

ncm_trivec_set_spherical_coord

Sets the spherical coordinates of a NcmTriVec. The spherical coordinates are the radius, the polar angle and the azimuthal angle. The polar angle is the angle between the vector and the z-axis, and the azimuthal angle is the angle between the projection of the vector in the xy-plane and the x-axis.