Struct

NumCosmoMathVarDict

Description [src]

struct NcmVarDict {
  /* No available fields */
}

Variable dictionary.

A NcmVarDict is a GHashTable that holds GVariants. It is used to store GVariants that can be serialized to a GVariant.

Constructors

ncm_var_dict_new

Creates a new NcmVarDict.

Functions

ncm_var_dict_clear

If vd is not NULL, unreferences it and sets vd to NULL.

Instance methods

ncm_var_dict_get_boolean

Gets a boolean from a NcmVarDict with key key.

ncm_var_dict_get_boolean_array

Gets an array of booleans from a NcmVarDict with key key.

ncm_var_dict_get_double

Gets a double from a NcmVarDict with key key.

ncm_var_dict_get_double_array

Gets an array of doubles from a NcmVarDict with key key.

ncm_var_dict_get_int

Gets an integer from a NcmVarDict with key key.

ncm_var_dict_get_int_array

Gets an array of integers from a NcmVarDict with key key.

ncm_var_dict_get_string

Gets a string from a NcmVarDict with key key.

ncm_var_dict_get_variant

Gets a GVariant from a NcmVarDict with key key.

ncm_var_dict_has_key

Checks if a NcmVarDict has a key key.

ncm_var_dict_keys

Gets the keys of a NcmVarDict.

ncm_var_dict_len

Gets the length of a NcmVarDict.

ncm_var_dict_ref

Increases the reference count of vd by one.

ncm_var_dict_set_boolean

Sets a boolean to a NcmVarDict. If there is already a boolean with key key, it is unreferenced.

ncm_var_dict_set_boolean_array

Sets an array of booleans to a NcmVarDict. If there is already an array of booleans with key key, it is unreferenced.

ncm_var_dict_set_double

Sets a double to a NcmVarDict. If there is already a double with key key, it is unreferenced.

ncm_var_dict_set_double_array

Sets an array of doubles to a NcmVarDict. If there is already an array of doubles with key key, it is unreferenced.

ncm_var_dict_set_int

Sets an integer to a NcmVarDict. If there is already an integer with key key, it is unreferenced.

ncm_var_dict_set_int_array

Sets an array of integers to a NcmVarDict. If there is already an array of integers with key key, it is unreferenced.

ncm_var_dict_set_string

Sets a string to a NcmVarDict. If there is already a string with key key, it is unreferenced.

ncm_var_dict_set_variant

Sets a GVariant to a NcmVarDict. If there is already a GVariant with key key, it is unreferenced.

ncm_var_dict_unref

Decreases the reference count of vd by one. If the reference count reaches zero, all objects in the dictionary are unreferenced.