Enumeration

NumCosmoMathMatrixInternal

Declaration

enum NumCosmoMath.MatrixInternal

Description [src]

This enumerator is only used internally. Only by developers.

Members

NCM_MATRIX_SLICE

Uses g_slice_* family functions from Glib to alloc and free memory segments.

  • Value: 0
  • Available since: 1.0
NCM_MATRIX_GSL_MATRIX

Uses gsl_matrix from GSL as the base object.

  • Value: 1
  • Available since: 1.0
NCM_MATRIX_MALLOC

Uses malloc for memory allocation and free functions.

  • Value: 2
  • Available since: 1.0
NCM_MATRIX_GARRAY

Uses g_array from Glib as base.

  • Value: 3
  • Available since: 1.0
NCM_MATRIX_DERIVED

Uses another NcmMatrix (for example, if it is getting a submatrix from a NcmMatrix).

  • Value: 4
  • Available since: 1.0