Struct

NumCosmoMathMemoryPool

Description [src]

struct NcmMemoryPool {
  /* No available fields */
}

Generic memory pool.

NcmMemoryPool is a generic memory pool, it alloc memory using a user defined function and save it for future use, the memory must be returned to the pool using

ncm_memory_pool_return. These functions are thread safe.

Functions

ncm_memory_pool_new

This function prepare a memory pool which allocate memory using mp_alloc and save it for future use, the memory must be returned to the pool using #ncm_memory_pool_return. These functions are thread safe.

ncm_memory_pool_return

Put the slice pointed by slice back to the pool.

Instance methods

ncm_memory_pool_add

Adds an already allocated pointer p to the pool. It will be freed with NcmMemoryPool->free during the pool destruction.

ncm_memory_pool_empty

This function free all the slices in the pool and also the slices if free_slices == TRUE and the pool was built with a free function.

ncm_memory_pool_free

This function free the memory pool and also the slices if free_slices == TRUE and the pool was built with a free function.

ncm_memory_pool_get

Search in the pool for a non used slice and return the first finded. If none allocate a new one add to the pool and return it.

ncm_memory_pool_set_min_size

If n grater than number of slices then allocate new slices until n == slices.