Enumeration
NumCosmoMathStatsVecType
Description [src]
Statistical types for vector statistics computation. These determine which statistical quantities are computed and stored during data accumulation.
Statistical types for vector statistics computation. These determine which statistical quantities are computed and stored during data accumulation.