Struct
NumCosmoMathSpline2dBicubicCoeffs
Description [src]
struct NcmSpline2dBicubicCoeffs {
/* No available fields */
}
Structure to hold the coefficients of a bicubic spline.
struct NcmSpline2dBicubicCoeffs {
/* No available fields */
}
Structure to hold the coefficients of a bicubic spline.