Enumeration
NumCosmoMathCSQ1DEvolState
Description [src]
Variables describing the system evolution state. The state NCM_CSQ1D_EVOL_STATE_ADIABATIC
is used to describe the adiabatic evolution of the system, this state use the frame
NCM_CSQ1D_FRAME_ADIAB1 with the variables $(\alpha,\, \delta\gamma)$ to compute the evolution.
The state NCM_CSQ1D_EVOL_STATE_UP and NCM_CSQ1D_EVOL_STATE_UM are used to describe the
non-adiabatic evolution of the system, these states use the frame #NCM_CSQ1D_FRAME_ORIG with
the variables $(\chi,\, U_+)$ and $(\chi,\, U_-)$ to compute the evolution, respectively.
Members
-
NCM_CSQ1D_EVOL_STATE_INVALID -
Invalid state.
- Value:
0 - Available since: 1.0
- Value:
-
NCM_CSQ1D_EVOL_STATE_ADIABATIC -
Adiabatic state variables $(\alpha,\, \delta\gamma)$.
- Value:
1 - Available since: 1.0
- Value:
-
NCM_CSQ1D_EVOL_STATE_UP -
$(\chi,\, U_+)$ state variables.
- Value:
2 - Available since: 1.0
- Value:
-
NCM_CSQ1D_EVOL_STATE_UM -
$(\chi,\, U_-)$ state variables.
- Value:
3 - Available since: 1.0
- Value: