Enumeration
NumCosmoMathMSetCatalogSync
Members
-
NCM_MSET_CATALOG_SYNC_DISABLE -
Catalog will be synchronized only when closing the file or with an explicit call of ncm_mset_catalog_sync().
- Value:
0 - Available since: 1.0
- Value:
-
NCM_MSET_CATALOG_SYNC_AUTO -
Catalog will be synchronized in every catalog addition.
- Value:
1 - Available since: 1.0
- Value:
-
NCM_MSET_CATALOG_SYNC_TIMED -
Catalog will be synchronized with a minimum time interval between syncs.
- Value:
2 - Available since: 1.0
- Value: