Enumeration
NumCosmoMathStatsVecARType
Description [src]
Autoregressive model selection criteria. These criteria are used to automatically select the optimal order for autoregressive models in time series analysis.
Members
-
NCM_STATS_VEC_AR_NONE -
Calculates using the required order.
- Value:
0 - Available since: 1.0
- Value:
-
NCM_STATS_VEC_AR_FPE -
Uses the FPE criterion to choose the ar order.
- Value:
1 - Available since: 1.0
- Value:
-
NCM_STATS_VEC_AR_AIC -
Uses the AIC criterion to choose the ar order.
- Value:
2 - Available since: 1.0
- Value:
-
NCM_STATS_VEC_AR_AICC -
Uses the AICc criterion to choose the ar order.
- Value:
3 - Available since: 1.0
- Value: