Struct
NumCosmoMathObjDictInt
Description [src]
struct NcmObjDictInt {
/* No available fields */
}
GObjects dictionary with integer keys.
A NcmObjDictInt is a GHashTable that holds GObject’s with integer keys. It is used
to store GObject’s that can be serialized to a GVariant.
Instance methods
ncm_obj_dict_int_peek
Peeks a GObject from a NcmObjDictInt with key key without increasing its reference count.
ncm_obj_dict_int_set
Sets a GObject to a NcmObjDictInt. If there is already a GObject
with key key, it is unreferenced.
ncm_obj_dict_int_unref
Decreases the reference count of odi by one. If the reference count
reaches zero, all objects in the dictionary are unreferenced.