API Version: 1.0
Library Version: 0.27.0
Generated by gi-docgen 2026.1
struct NcmComplex { /* No available fields */ }
No description available.
Allocates a new complex number.
Frees c and sets c to NULL, it should not be used on a statically allocated NcmComplex.
c
Returns the absolute value of c.
Returns the imaginary part of c.
Returns the real part of c.
Allocates a new complex number and copy the contents of c to it.
Frees c, it should not be used on a statically allocated NcmComplex.
Computes c1 = c1 * v.
c1
v
Computes c1 = c1 + c2 * c3, assuming that c1 and c2 are different.
c2
c3
Computes c1 = c1 + c2 * v, assuming that c1 and c2 are different.
Computes c1 = c1 * c2, assuming that c1 and c2 are different.
Sets c to $a + I b$.
Sets c to $0 + I 0$.
Content