Struct
NumCosmoMathMSetFuncListStruct
Description [src]
struct NcmMSetFuncListStruct {
gchar* name;
gchar* symbol;
gchar* ns;
gchar* desc;
}
Structure defining a function in the model set function list. This holds metadata for functions that can be evaluated on model parameter sets.
Structure members
name:gchar*Function name identifier.
symbol:gchar*Mathematical symbol or LaTeX representation.
ns:gchar*Namespace for the function.
desc:gchar*Human-readable description of the function.