Struct
NumCosmoMathRNGDiscrete
Constructors
ncm_rng_discrete_new
Creates a new NcmRNGDiscrete. This object is used to generate random numbers
from a discrete distribution for the given set of weights.
Creates a new NcmRNGDiscrete. This object is used to generate random numbers
from a discrete distribution for the given set of weights.