Struct
NumCosmoMathObjArray
Description [src]
struct NcmObjArray {
/* No available fields */
}
GObjects array with serialization support.
A NcmObjArray is a GPtrArray that holds GObject’s. It is used to store GObject’s
that can be serialized to a GVariant.
Instance methods
ncm_obj_array_peek
Peeks a GObject from a NcmObjArray at position i without increasing its reference count.
ncm_obj_array_set
Sets a GObject to a NcmObjArray. If there is already a GObject
at position i, it is unreferenced.
ncm_obj_array_unref
Decreases the reference count of oa by one. If the reference count
reaches zero, all objects in the array are unreferenced.