Struct
NumCosmoMathObjDictStr
Description [src]
struct NcmObjDictStr {
/* No available fields */
}
GObjects dictionary with string keys.
A NcmObjDictStr is a GHashTable that holds GObject’s with string keys. It is used
to store GObject’s that can be serialized to a GVariant.
Instance methods
ncm_obj_dict_str_peek
Peeks a GObject from a NcmObjDictStr with key key without increasing its reference count.
ncm_obj_dict_str_set
Sets a GObject to a NcmObjDictStr. If there is already a GObject
with key key, it is unreferenced.
ncm_obj_dict_str_unref
Decreases the reference count of ods by one. If the reference count
reaches zero, all objects in the dictionary are unreferenced.