Processors#
Data Processors#
General#
|
Exact-hash-based deduplication for text, binary data, or files. |
Text#
|
Markdown-aware structural text chunking operator. |
|
Text fuzzy deduplication using MinHashLSH. |
Implements a scalable, distributed exact substring deduplication algorithm using a divide-and-conquer strategy. |
|
Unified text chunking operator with multiple strategies. |
|
|
Compute the ratio of flagged words in a text. |
Audio#
|
Image#
|
Video#
|
AI Processors#
Text#
|
Text Embedding processor for CPU, GPU and remote Http requests. |
|
TextSummarize processor provides a highly condensed summary of the text. |
|
TextMask processor replaces sensitive information in the original text with [MASKED] according to the labels. |
|
TextGenerate processor generates content based on the input parameters. |
|
TextClassify processor extracts the single label that best matches the text content. |
|
TextFixGrammar processor corrects grammar mistakes in the input text using LLM model. |
|
TextSimilarity processor calculates similarity between texts using LLM model. |
|
TextTranslate processor responsible for translating the text into the target language. |
|
TextSentiment processor for text sentiment analysis. |
|
TextExtract processor extracts structured information from text based on user-defined |
|
TextPredicateEval processor evaluates whether input texts satisfy a given predicate condition. |
|
Computes the perplexity of text using a language model to evaluate fluency and naturalness. |
Language detection operator based on a fasttext model. |
|
Language score operator based on a fasttext model. |
|
|
Supports two usage modes: |
Image#
|
Image NSFW score calculation processor for CPU, GPU |
Image text similarity score calculation processor for CPU, GPU |
|
Image aesthetic score calculation processor for CPU, GPU. |
Audio#
|
Speech to text processor for CPU, GPU and remote Http requests. |
Time Series#
Time-series forecasting processor backed by Chronos-2. |
Connectors#
VectorDB#
Operator for batch-inserting records into a vector database. |
|
Operator for batch-upserting records into a vector database. |
|
Operator for batch-deleting records from a vector database by ID. |
|
Operator for vector similarity search with optional metadata filtering. |