Troubleshooting

Quick troubleshooting

The AI Assistant lives in the Local cluster in the cattle-ai-agent-system namespace. Agent Logs can be accessed to understand any issues.

kubectl get po -n cattle-ai-agent-system

To get logs from the ‘rancher-ai-agent’ pod:

kubectl logs -n cattle-ai-agent-system -l app=rancher-ai-agent

To get logs from the ‘rancher-ai-mcp’ pod:

kubectl logs -n cattle-ai-agent-system -l app=rancher-mcp-server

Enable debug log

You can enable debugs log, using log.level=debug during the helm deployment of the Agent.

helm upgrade --install --set log.level=debug rancher-ai-agent rancher-ai/agent

Rancher behind insecure certificate

If your Rancher manager is using a self-signed certificate, please use insecureSkipTls=true to allow the MCP server to connect to Rancher.

helm upgrade --install --set insecureSkipTls=true rancher-ai-agent rancher-ai/agent