Troubleshooting
Quick troubleshooting
The AI Assistant lives in the Local cluster in the cattle-ai-agent-system
namespace. Agent Logs can be accessed to understand any issues.
kubectl get po -n cattle-ai-agent-system
To get logs from the ‘rancher-ai-agent’ pod:
kubectl logs -n cattle-ai-agent-system -l app=rancher-ai-agent
To get logs from the ‘rancher-ai-mcp’ pod:
kubectl logs -n cattle-ai-agent-system -l app=rancher-mcp-server